NAME
Quizzer::AutoSelect -- automatic FrontEnd selection library.
DESCRIPTION
This library makes it easy to create FrontEnd and ConfModule objects. It starts with the desired type of object, and tries to make it. If that fails, it progressivly falls back to other types.
METHODS
frontend
Creates and returns a FrontEnd object.
AUTHOR
Joey Hess <joey@kitenet.net>